@@ -15,7 +15,7 @@ from typing import List
 
 import numpy as np
 
-from .bboxutils import BBOXAnnotate, BBOXConfig, BBoxSort, BBoxUtils
+from .bboxutils import BBOXAnnotate, BBoxSort, BBoxUtils
 
 # Constants
 LeftAlignment="LeftAlignment"
@@ -24,16 +24,14 @@ CenteredAlignment="CenteredAlignment"
 
 Alignments = [LeftAlignment,RightAlignment,CenteredAlignment]
 
-# Load deafult Configuration
-json_file_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), "config/config.json")
-with open(json_file_path) as json_file:
-    bboxconfig=BBOXConfig.from_json(json.loads(json_file.read()))
+global bboxconfig
+global bboxlogger 
 
-# Load Logging default configuration 
-log_file_path = path.join(path.dirname(path.abspath(__file__)), 'config/logging.conf')
-logging.config.fileConfig(log_file_path)
-bboxlogger = logging.getLogger('bboxhelper')  # get a logger
-bboxlogger.setLevel(logging.INFO)
+from .bboxconfig import BBOXConfig
+bboxconfig = BBOXConfig.get_config()
+
+from . import bboxlog
+bboxlogger = bboxlog.get_logger()
 
 # Load Default HTML Annotations
 json_file_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), "config/annotations.json")
@@ -172,26 +170,29 @@ class BBOXPageLayout():
         self.lines=Lines
         self.ppi=ppi
     @classmethod
-    def from_azure(cls, data):
-        if data["unit"]=="inch":
+    def from_azure(cls, page):
+        bboxlogger.debug("Azure|Page shape (Height,Width) ({0},{1})".format(page["width"],page["height"]))
+        # TODO #1
+        if page["unit"]=="inch":
             # Azure OCR response doesn't provide the ppi per page
             # so we need to determine it for normalizing the processing of lines
-            ppi=BBoxUtils.determine_ppi(data["width"],data["height"])
+            # ppi=BBoxUtils.determine_ppi(data["width"],data["height"])
+            
             # decimal precision on Azure is set to 4, so we can set a 10000 to normalize the box and 
             # not convert to pixel
             ppi=10000
         else:
             ppi=1
 
-        lines=[BBOXNormalizedLine.from_azure(i,line, 1) for i,line in enumerate(data["lines"])] 
+        lines=[BBOXNormalizedLine.from_azure(i,line, 1) for i,line in enumerate(page["lines"])] 
         # >=0.6.0
-        if "angle" in data:
-            angle = data["angle"]
+        if "angle" in page:
+            angle = page["angle"]
         # <= 0.5.0
-        elif "clockwiseorientation" in data:
-            angle = data["clockwiseorientation"]
+        elif "clockwiseorientation" in page:
+            angle = page["clockwiseorientation"]
           
-        return cls(Id=data["page"],clockwiseorientation=angle,Width=data["width"],Height=data["height"],Unit=data["unit"],Lines=lines,ppi=ppi)
+        return cls(Id=page["page"],clockwiseorientation=angle,Width=page["width"],Height=page["height"],Unit=page["unit"],Lines=lines,ppi=ppi)
 
     @classmethod
     def from_google(cls, page):
@@ -290,7 +291,7 @@ class BBOXOCRResponse():
 
 class BBoxHelper():
 
-    # Support to use a custom configuration file.
+    # Support to use a custom configuration, annotation and logging file.
     def __init__(self, customcfgfilepath=None, customlogfilepath=None, annotate=False, annotationconfig=None,verbose=None):
         global bboxlogger,bboxconfig,bboxannotate
         if customcfgfilepath:
@@ -306,10 +307,13 @@ class BBoxHelper():
         if annotationconfig:
             bboxannotate=BBOXAnnotate.from_json(json.loads(annotationconfig))
 
-    def processAzureOCRResponse(self,input,sortingAlgo=BBoxSort.contoursSort,boxSeparator:str = None):
+    def processAzureOCRResponse(self,input,sortingAlgo=BBoxSort.contoursSort,boxSeparator:str = None,verbose=None):
         """ processAzureOCRResponse method
             Process an OCR Response input from Azure and returns a new BBox format OCR response.
         """
+        if verbose:
+            bboxlogger.setLevel(logging.DEBUG)
+
         #load the input json into a response object
         if isinstance(input,str):
             response=BBOXOCRResponse.from_azure(json.loads(input))
@@ -320,10 +324,13 @@ class BBoxHelper():
 
         return self.__processOCRResponse(response,sortingAlgo,boxSeparator)
 
-    def processGoogleOCRResponse(self,input,sortingAlgo=BBoxSort.contoursSort,boxSeparator:str = None):
+    def processGoogleOCRResponse(self,input,sortingAlgo=BBoxSort.contoursSort,boxSeparator:str = None,verbose=None):
         """ processGoogleOCRResponse method
             Process an OCR Response input from Google and returns a new BBox format OCR response.
         """
+        if verbose:
+            bboxlogger.setLevel(logging.DEBUG)
+            
         #Create an BBOXOCRResponse object from Google input
         response=BBOXOCRResponse.from_google(input)
 
@@ -340,11 +347,11 @@ class BBoxHelper():
 
         # Rotate the BBox of each page based on its corresponding orientation
         for page in response.pages:
-            bboxlogger.debug("Processing Page {0} with {1} lines.".format(str(page.id),len(page.lines)))
+            bboxlogger.debug("{0}|Processing Page {0} with {1} lines.".format(str(page.id),len(page.lines)))
             if self.annotate and bboxannotate.pageTag:
                 newtext+=bboxannotate.pageTag[0]
             rotation = round(page.clockwiseorientation,0)
-            bboxlogger.debug("Orientation {}".format(str(rotation)))
+            bboxlogger.debug("{0}|Orientation {1}".format(str(page.id),str(rotation)))
             page_width=page.width
             page_height=page.height
             # Bounding Boxes Orientation
@@ -391,13 +398,13 @@ class BBoxHelper():
                 page.width = page_height
                 page.height = page_width
             else:
-                bboxlogger.info("TODO rotation adjustment required ? ")
+                bboxlogger.warning("TODO rotation adjustment required ? ")
 
             # Invoke the page processing
             page = self.processOCRPageLayout(page, sortingAlgo, boxSeparator)
             newtext += page.text
 
-            bboxlogger.debug("Processed Page {0} with {1} bbox lines.".format(str(page.id),len(page.lines)))
+            bboxlogger.debug("{0}|Processed Page {0} with {1} bbox lines.".format(str(page.id),len(page.lines)))
 
             if self.annotate and bboxannotate.pageTag:
                 newtext+=bboxannotate.pageTag[1]
@@ -525,7 +532,6 @@ class BBoxHelper():
         #
         # Page lines Sorting
         # 
-
         if sortingAlgo is None:
             # Old Default Sorting Strategy 
             # Based on the W/H ratio we set the sorting strategy
@@ -543,7 +549,7 @@ class BBoxHelper():
         else:
             sortedBlocks = sortingAlgo(page.id,page.width,page.height,blocks=outlines,scale=page.ppi)
 
-        bboxlogger.debug("{1}|Output {0} lines after  sorting...".format(len(sortedBlocks),str(page.id)))
+        bboxlogger.debug("{1}|Output {0} lines after sorting...".format(len(sortedBlocks),str(page.id)))
 
         # Output the actual from the sorted blocks
         newtext = ""
